@@ -40,14 +40,14 @@ public:
     kpToolColorPickerCommand (int mouseButton,
                               const kpColor &newColor, const kpColor &oldColor,
                               kpCommandEnvironment *environ);
-    virtual ~kpToolColorPickerCommand ();
+    ~kpToolColorPickerCommand () override;
 
-    QString name () const Q_DECL_OVERRIDE;
+    QString name () const override;
 
-    SizeType size () const Q_DECL_OVERRIDE;
+    SizeType size () const override;
 
-    void execute () Q_DECL_OVERRIDE;
-    void unexecute () Q_DECL_OVERRIDE;
+    void execute () override;
+    void unexecute () override;
 
 private:
     int m_mouseButton;
